@@ -18,7 +18,7 @@ from pi3d.constants import (bcm, openegl, opengles,
     EGL_STENCIL_SIZE, EGL_SURFACE_TYPE, EGL_WIDTH, EGL_WINDOW_BIT,
     EGLint, GL_BACK, GL_CULL_FACE, GL_CW, GL_DEPTH_TEST, GL_FRAMEBUFFER,
     GL_GENERATE_MIPMAP_HINT, GL_LESS, GL_NICEST, GL_ONE_MINUS_SRC_ALPHA,
-    GL_POINT_SPRITE, GL_PROGRAM_POINT_SIZE, GL_SRC_ALPHA, GL_VERSION,
+    GL_POINT_SPRITE, GL_PROGRAM_POINT_SIZE, GL_SRC_ALPHA, GL_VERSION, GL_MAX_TEXTURE_SIZE,
     PLATFORM, PLATFORM_ANDROID, PLATFORM_PI, PLATFORM_WINDOWS)
 
 if not (pi3d.USE_PYGAME or PLATFORM in (PLATFORM_ANDROID, PLATFORM_PI, PLATFORM_WINDOWS)):
@@ -43,7 +43,7 @@ if pi3d.USE_PYGAME:
 class DisplayOpenGL(object):
   def __init__(self):
     self.d = None # display if x11 window or pygame used
-    self.gl_id = "GL" # default. Needed for converting shaders
+    self.gl_id = b"GL" # default. Needed for converting shaders
     if PLATFORM == PLATFORM_ANDROID:
       self.width, self.height = 320, 480 # put in some non-zero place-holders
     elif PLATFORM == PLATFORM_PI:
@@ -123,24 +123,6 @@ class DisplayOpenGL(object):
     opengles.glClearColor (GLfloat(0.3), GLfloat(0.3), GLfloat(0.7), GLfloat(1.0))
     opengles.glBindFramebuffer(GL_FRAMEBUFFER, GLuint(0))
 
-    #Setup default hints
-    opengles.glEnable(GL_CULL_FACE)
-    opengles.glCullFace(GL_BACK)
-    opengles.glFrontFace(GL_CW)
-    opengles.glEnable(GL_DEPTH_TEST)
-    opengles.glEnable(GL_PROGRAM_POINT_SIZE)
-    opengles.glEnable(GL_POINT_SPRITE)
-    opengles.glDepthFunc(GL_LESS)
-    opengles.glDepthMask(GLboolean(True))
-    opengles.glHint(GL_GENERATE_MIPMAP_HINT, GL_NICEST)
-    opengles.glBlendFuncSeparate(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA, 
-                                       1, GL_ONE_MINUS_SRC_ALPHA)
-    opengles.glColorMask(GLboolean(True), GLboolean(True), GLboolean(True), GLboolean(False))
-    #opengles.glEnableClientState(GL_VERTEX_ARRAY)
-    #opengles.glEnableClientState(GL_NORMAL_ARRAY)
-
-    self.active = True
-
     # get GL v GLES and version num for shader translation
     version = opengles.glGetString(GL_VERSION)
     version = ctypes.cast(version, c_char_p).value
@@ -150,6 +132,30 @@ class DisplayOpenGL(object):
           self.gl_id = b"GLES" + s.split(b'.')[0]
           break
 
+    #Setup default hints
+    opengles.glEnable(GL_CULL_FACE)
+    opengles.glCullFace(GL_BACK)
+    opengles.glFrontFace(GL_CW)
+    opengles.glEnable(GL_DEPTH_TEST)
+    if b"GLES" not in self.gl_id:
+      if b"2" in self.gl_id:
+        opengles.glEnable(GL_VERTEX_PROGRAM_POINT_SIZE)
+      else:
+        opengles.glEnable(GL_PROGRAM_POINT_SIZE) # only in > GL3
+      opengles.glEnable(GL_POINT_SPRITE)
+    opengles.glDepthFunc(GL_LESS)
+    opengles.glDepthMask(GLboolean(True))
+    opengles.glHint(GL_GENERATE_MIPMAP_HINT, GL_NICEST)
+    opengles.glBlendFuncSeparate(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA, 
+                                       1, GL_ONE_MINUS_SRC_ALPHA)
+    opengles.glColorMask(GLboolean(True), GLboolean(True), GLboolean(True), GLboolean(False))
+    #opengles.glEnableClientState(GL_VERTEX_ARRAY)
+    #opengles.glEnableClientState(GL_NORMAL_ARRAY)
+    self.max_texture_size = GLint(0)
+    opengles.glGetIntegerv(GL_MAX_TEXTURE_SIZE, byref(self.max_texture_size))
+
+    self.active = True
+
   def create_surface(self, x=0, y=0, w=0, h=0, layer=0):
     #Set the viewport position and size
     dst_rect = c_ints((x, y, w, h))
